==> bcc-core-api-node-sdk-1.7.0.tgz: package/lib/esm/test/auth.js <==
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
import { assert } from "chai";
import { delay } from "./helpers";
import { Auth } from "../api/auth";
import Sinon from "sinon";
import { defaultEnvironmentConfig } from "../configuration/environments";
import { Environment } from "../model/environment";
describe("Auth", () => __awaiter(void 0, void 0, void 0, function* () {
    const auth = new Auth({
        audience: defaultEnvironmentConfig[Environment.Emulator].oauthAudience,
        clientId: "0000",
        clientSecret: "0000",
        tokenUrl: defaultEnvironmentConfig[Environment.Emulator].tokenUrl
    });
    it("Authenticate token gets reused", () => __awaiter(void 0, void 0, void 0, function* () {
        const t1 = yield auth.getToken();
        yield delay(1000);
        const t2 = yield auth.getToken();
        assert.equal(t1, t2);
    }));
    it("Authenticate expired token gets refreshed", () => __awaiter(void 0, void 0, void 0, function* () {
        const t1 = yield auth.getToken();
        yield delay(1000);
        const fakeClock = Sinon.useFakeTimers(new Date());
        fakeClock.tick(2 * 24 * 60 * 60 * 1000);
        const t2 = yield auth.getToken();
        fakeClock.restore();
        assert.notEqual(t1, t2);
    }));
}));

==> bcc-core-api-node-sdk-1.7.1.tgz: package/lib/esm/test/auth.js <==
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
import { assert } from "chai";
import { delay } from "./helpers";
import { Auth } from "../api/auth";
import Sinon from "sinon";
import { Environment, defaultEnvironmentConfig, } from "../configuration/environments";
describe("Auth", () => __awaiter(void 0, void 0, void 0, function* () {
    const auth = new Auth({
        audience: defaultEnvironmentConfig[Environment.Emulator].oauthAudience,
        clientId: "0000",
        clientSecret: "0000",
        tokenUrl: defaultEnvironmentConfig[Environment.Emulator].tokenUrl,
    });
    it("Authenticate token gets reused", () => __awaiter(void 0, void 0, void 0, function* () {
        const t1 = yield auth.getToken();
        yield delay(1000);
        const t2 = yield auth.getToken();
        assert.equal(t1, t2);
    }));
    it("Authenticate expired token gets refreshed", () => __awaiter(void 0, void 0, void 0, function* () {
        const t1 = yield auth.getToken();
        yield delay(1000);
        const fakeClock = Sinon.useFakeTimers(new Date());
        fakeClock.tick(2 * 24 * 60 * 60 * 1000);
        const t2 = yield auth.getToken();
        fakeClock.restore();
        assert.notEqual(t1, t2);
    }));
}));
